@@ -45,7 +45,7 @@ QT_BEGIN_NAMESPACE
 /*!
     \qmltype CandlestickSeries
     \since QtCharts 2.2
-    \instantiates QCandlestickSeries
+    \nativetype QCandlestickSeries
     \inqmlmodule QtCharts
     \inherits AbstractSeries
     \brief Represents a series of data as candlesticks.
@@ -86,7 +86,8 @@ QT_BEGIN_NAMESPACE
     \endcode
 
     \beginfloatleft
-    \image examples_qmlcandlestick.png
+    \image examples_qmlcandlestick.png {Screenshot showing a candlestick
+           series example with the x axis describing date times}
     \endfloat
     \clearfloat
 
@@ -975,10 +976,10 @@ void QCandlestickSeriesPrivate::initializeGraphics(QGraphicsItem *parent)
     QAbstractSeriesPrivate::initializeGraphics(parent);
 
     if (m_chart) {
-        connect(m_chart->d_ptr->m_dataset, SIGNAL(seriesAdded(QAbstractSeries *)),
-                this, SLOT(handleSeriesChange(QAbstractSeries *)));
-        connect(m_chart->d_ptr->m_dataset, SIGNAL(seriesRemoved(QAbstractSeries *)),
-                this, SLOT(handleSeriesRemove(QAbstractSeries *)));
+        connect(m_chart->d_ptr->m_dataset, SIGNAL(seriesAdded(QAbstractSeries*)),
+                this, SLOT(handleSeriesChange(QAbstractSeries*)));
+        connect(m_chart->d_ptr->m_dataset, SIGNAL(seriesRemoved(QAbstractSeries*)),
+                this, SLOT(handleSeriesRemove(QAbstractSeries*)));
 
         item->handleCandlestickSeriesChange();
     }
